@@ -1,16 +1,17 @@
 package PPIx::EditorTools::ReturnObject;
 
-# ABSTRACT: Simple object to return values from PPIx::EditorTools
-
-use 5.008;
 use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.15_04';
+our $VERSION = '0.04';
 
 =pod
 
+=head1 NAME
+
+PPIx::EditorTools::ReturnObject - Simple object to return values from PPIx::EditorTools 
+
 =head1 SYNOPSIS
 
   my $brace = PPIx::EditorTools::FindUnmatchedBrace->new->find(
@@ -27,9 +28,9 @@ C<PPIx::EditorTools::ReturnObject> provides an object that can be passed
 around which retains the overall context.
 
 For example, in C<PPIx::EditorTools::FindUnmatchedBrace> if the unmatched
-brace were returned by its C<PPI::Structure::Block> the containing
+brace were returned by its C<PPI::Structure::Block> the containing 
 C<PPI::Document> is likely to go out of scope, thus the C<location>
-method no longer returns a valid location (rather it returns undef).
+method no longer returns a valid location (rather it returns undef). 
 Using the C<ReturnObject> preserves the C<PPI::Document> and the containing
 context.
 
@@ -73,54 +74,54 @@ from the C<PPI::Document> via the serialize method (lazily) if needed.
 =cut
 
 sub new {
-	my $class = shift;
-	return bless {@_}, ref($class) || $class;
+    my $class = shift;
+    return bless {@_}, ref($class) || $class;
 }
 
 sub element {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	# If element is a code ref, run the code once then cache the
-	# result
-	if (    exists $self->{element}
-		and ref( $self->{element} )
-		and ref( $self->{element} ) eq 'CODE' )
-	{
-		$self->{element} = $self->{element}->(@_);
-	}
+    # If element is a code ref, run the code once then cache the
+    # result
+    if (    exists $self->{element}
+        and ref( $self->{element} )
+        and ref( $self->{element} ) eq 'CODE' )
+    {
+        $self->{element} = $self->{element}->(@_);
+    }
 
-	return $self->{element};
+    return $self->{element};
 }
 
 sub ppi {
-	my ( $self, $doc ) = @_;
+    my ( $self, $doc ) = @_;
 
-	# $self->{ppi} = $doc if $doc;    # TODO: and isa?
+    # $self->{ppi} = $doc if $doc;    # TODO: and isa?
 
-	return $self->{ppi} if $self->{ppi};
+    return $self->{ppi} if $self->{ppi};
 
-	if ( $self->{code} ) {
-		my $code = $self->{code};
-		$self->{ppi} = PPI::Document->new( \$code );
-		return $self->{ppi};
-	}
+    if ( $self->{code} ) {
+        my $code = $self->{code};
+        $self->{ppi} = PPI::Document->new( \$code );
+        return $self->{ppi};
+    }
 
-	return;
+    return;
 }
 
 sub code {
-	my ( $self, $doc ) = @_;
+    my ( $self, $doc ) = @_;
 
-	# $self->{code} = $doc if $doc;
+    # $self->{code} = $doc if $doc;
 
-	return $self->{code} if $self->{code};
+    return $self->{code} if $self->{code};
 
-	if ( $self->{ppi} ) {
-		$self->{code} = $self->{ppi}->serialize;
-		return $self->{code};
-	}
+    if ( $self->{ppi} ) {
+        $self->{code} = $self->{ppi}->serialize;
+        return $self->{code};
+    }
 
-	return;
+    return;
 }
 
 1;
@@ -131,6 +132,17 @@ __END__
 
 C<PPIx::EditorTools>, L<App::EditorTools>, L<Padre>, and L<PPI>.
 
+=head1 AUTHOR
+
+Mark Grimes C<mgrimes@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2008-2009 The Padre development team as listed in Padre.pm.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl 5 itself.
+
 =cut
 
 # Copyright 2008-2009 The Padre development team as listed in Padre.pm.
